<template>
  <div class="mobile-container">
    <van-sticky class="containter-sticky">
      <navBar @clickLeft="onClickLeft" :title="title"></navBar>
      <!-- <navBar
  @clickLeft="onClickLeft"
  @clickRight="realtimeData"
  :leftText="title"
  rightText="实时数据"
></navBar> -->
    </van-sticky>
    <van-cell-group inset class="device-group">
      <div class="device-cell">
        <div class="device-name">
          <!-- <van-icon name="label" color="#1989fa" /> -->
          {{ deviceData.name }}
        </div>
        <div class="device-status">
          <van-tag type="success" v-if="deviceData.status == 1"
          >正常
          </van-tag
          >
          <van-tag type="warning" v-if="deviceData.status == 2"
          >故障
          </van-tag
          >
          <van-tag type="danger" v-if="deviceData.status == 3"
          >报警
          </van-tag
          >
        </div>
      </div>
      <div class="device-content">
        <!-- <p>
            <span style="color: #333">所属区域：</span
            >{{ deviceData.areaName }}
        </p>
        <p>
            <span style="color: #333">产品名称：</span
            >{{ deviceData.productName }}
        </p> -->
        <van-cell-group inset>
          <van-cell title="所属区域:" :value="deviceData.areaName" />
          <van-cell
            title="产品名称:"
            :value="deviceData.productName"
          />
        </van-cell-group>
      </div>
    </van-cell-group>
    <div class="basic-information">
      <div class="group-title">基础信息</div>
      <van-cell-group inset>
        <van-cell title="设备标识:" :value="deviceData.code" />
        <van-cell title="使用年限:" :value="deviceData.life" />
        <van-cell
          title="重点设备:"
          :value="deviceData.important == 1 ? '是' : '否'"
        />
        <van-cell title="设备经度:" :value="deviceData.lgtd" />
        <van-cell title="设备纬度:" :value="deviceData.lttd" />
        <van-cell title="安装详细地址:" :value="deviceData.address" />
        <van-cell title="设备供应商:" :value="deviceData.companyName" />
        <van-cell
          title="设备管理人员:"
          :value="deviceData.managerUserName"
        />
        <van-cell
          title="设备维护人员:"
          :value="deviceData.repairUserName"
        />
        <van-cell title="备注:" :value="deviceData.memo" />
      </van-cell-group>
    </div>

    <div class="group-title" v-if="extendParams.length">
      <span class="title-bar"></span>扩展参数
    </div>
    <van-cell-group inset>
      <van-cell
        :title="item.name + ':'"
        :value="item.transformValue"
        v-for="item in extendParams"
        :key="item.id"
      />
    </van-cell-group>
    <div style="height: 16px" v-if="extendParams.length"></div>
  </div>
</template>

<script>
import dictUtils from '@/components/dict/DictSelectUtils.js'
import equipmentManage from '@/api/device/equipmentManage.js'
import navBar from '../components/navBar.vue'

export default {
  name: 'DeviceDetail',
  components: {
    navBar
  },
  data() {
    return {
      title: '设备详情',
      deviceData: {},
      paramsValueList: [],
      extendParams: [],
      loading: false
    }
  },
  mounted() {
    this.deviceStatus = dictUtils.getDictItemsFromCache('sbzt')
    this.deviceAzlc = dictUtils.getDictItemsFromCache('azlc')
    this.deviceAzddlx = dictUtils.getDictItemsFromCache('azddlx')
    this.device = this.$route.query.id
    this.getDevice(this.device)
  },
  methods: {
    onClickLeft() {
      this.$router.go(-1)
    },
    // realtimeData() {
    //   this.$router.push({
    //     name: 'RealtimeData',
    //     query: {id: this.device}
    //   })
    // },
    getDevice(id) {
      equipmentManage.deviceDetailsInfo(id, (res) => {
        this.deviceData = res // 设备详情
        this.deviceAzlc.forEach((item) => {
          if (item.value == this.deviceData.floor) {
            this.deviceData.floorName = item.name
          }
        })
        this.deviceAzddlx.forEach((item) => {
          if (item.value == this.deviceData.addressType) {
            this.deviceData.addressTypeName = item.name
          }
        })
        console.log(this.deviceData, '设备详情')
      })

      equipmentManage.deviceDetails(id, (res) => {
        this.paramsValueList = res.paramsValueList // 设备扩展参数数据
        equipmentManage.getExtendParams({deviceId: id}, (res) => {
          // 设备扩展参数配置
          if (res.length) {
            this.extendParams = res
            this.extendParams.forEach((item) => {
              this.paramsValueList.forEach((val) => {
                if (item.id == val.confId) {
                  item['value'] = val.value
                  item.transformValue = val.value
                }
              })
              if (
                item.ctlType == 'select' ||
                item.ctlType == 'radio'
              ) {
                let arr = JSON.parse(item.json)
                arr.forEach((i) => {
                  if (item.value == i.value) {
                    item.transformValue = i.label
                  }
                })
              } else if (item.ctlType == 'checkbox') {
                let arr = JSON.parse(item.json)
                let arr1 = item.value.split(',')

                let itemArr = null
                let str = []
                arr.forEach((i) => {
                  if (arr1.indexOf(i.value) !== -1) {
                    str.push(i.label)
                    itemArr = str.toString()
                  }
                })
                item.transformValue = itemArr
              }
            })
          }
        })
      })
    }
  }
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';

.mobile-container {
  width: 100%;
  min-height: 100%;
  background-color: #f9f9f9 !important;
  padding: 50px;
  box-sizing: border-box;
  // background-color: $--mobile-bg;
  .containter-sticky {
    position: fixed;
    top: 0;
    width: 100%;
    z-index: 200;
  }
}

.van-cell {
  padding: 20px;

  .van-cell__title {
    span {
      color: #333;
    }
  }

  .van-cell__value {
    span {
      color: #666;
    }
  }
}

.van-cell::after {
  border-bottom: 0px solid #dddddd;
}

.basic-information {
  margin-top: 50px;
  padding: 50px;
  border-radius: 50px;
  background-color: white;
}

::v-deep .device-cell[data-v-81548ea6] {
  border-bottom: 0;
}

::v-deep .van-nav-bar .van-icon {
  color: white !important;
}

::v-deep .van-nav-bar__content {
  height: 9vw !important;
  background-color: #469ff7;

  .van-nav-bar__title {
    color: white;
  }
}

.device-content {
  // padding: 50px 0px 50px 0px;
  height: 400px;
  font-size: 50px;

  p {
    color: #929494;
    margin: 10px 0 10px 0;
  }
}

.device-group {
  padding: 0 60px 0 60px;
  margin-top: 16px !important;
}

.group-title {
  padding: 20px 16px 10px 16px;
  color: #888888;
  font-size: 78px;
}

.title-bar {
  display: inline-block;
  width: 4px;
  height: 12px;
  background-color: #1989fa;
  margin-right: 4px;
  vertical-align: middle;
}

.device-cell {
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 40px 0 40px 0;
  border-bottom: 1px solid #dedddd;
}

.device-name {
  font-size: 72px;
  color: $--mobile-text-main;
}

.cell-title {
  color: $--mobile-text-sub;
  font-size: 72px;
  margin-right: 10px;
}

.cell-value {
  color: $--mobile-text-main;
  font-size: 72px;
}

.margin-bottom {
  margin-bottom: 16px !important;
}

.device-status .van-tag {
  padding: 10px 40px 10px 40px;
  font-size: 72px;
}

.van-cell-group--inset {
  margin: 0 0;
  border-radius: 50px !important;
}

.van-cell {
  justify-content: start;
}

.van-cell__title,
.van-cell__value {
  width: auto;
  flex: initial;
}

.van-cell__title {
  white-space: nowrap;
}

.van-cell__value {
  padding-left: 10px;
  text-align: left;
}

.van-cell__title span,
.van-cell__value span {
  font-size: 60px;
  color: $--mobile-text-main;
}

.van-cell__title span {
  color: $--mobile-text-sub;
}
</style>
<style lang="scss">
@import '@/assets/css/vant-custom.scss';
</style>
